﻿using System;
using Microsoft.SharePoint;

namespace Layer2.Products.BdlcApiExamples
{
    class BdlcConfigList
    {
       internal static SPList GetList(SPWeb currentWeb)
        {
            SPList configurationList;
            SPWeb rootweb = currentWeb.Site.RootWeb;

            // normally we hold the Guid of the BDLC Configuration list in the PropertyBag of the current site.
            Guid listId = GetUniqueIdFromPropertyBag(rootweb);
            // if the Guid is not present in the bag, just load it the old fashioned way
            if (listId == Guid.Empty)
                configurationList = LoadListFromPath(rootweb);
            else
            {
                try
                {
                    configurationList = rootweb.Lists[listId];
                }
                catch (Exception)
                {
                    // if the List cant be retrieved, try it to load it by its URL
                    configurationList = LoadListFromPath(rootweb);
                }
            }

            return configurationList;
        }
     
        internal static Guid GetUniqueIdFromPropertyBag(SPWeb web)
        {
            if (web.AllProperties.ContainsKey(Constants.BDLC_CONFIGURATION_LIST_INTERNALNAME))
            {
                string guidAsString = web.AllProperties[Constants.BDLC_CONFIGURATION_LIST_INTERNALNAME] as string;
                if (!String.IsNullOrEmpty(guidAsString))
                    return new Guid(guidAsString);
            }
            return Guid.Empty;
        }

        internal static SPList LoadListFromPath(SPWeb web)
        {
            string url = $"{web.ServerRelativeUrl}/Lists/{Constants.BDLC_CONFIGURATION_LIST_INTERNALNAME}";
            url = url.Replace("//", "/");
            return web.GetList(url);
        }
    }
}
